#
# spec file for package python-Flask-SQLAlchemy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Flask-SQLAlchemy
Version:        2.3.2
Release:        lp151.1.1
Summary:        SQLAlchemy support for Flask
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://github.com/mitsuhiko/flask-sqlalchemy
Source:         https://files.pythonhosted.org/packages/source/F/Flask-SQLAlchemy/Flask-SQLAlchemy-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 0.10
Requires:       python-SQLAlchemy >= 0.8.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Flask >= 0.10}
BuildRequires:  %{python_module SQLAlchemy >= 0.8.0}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Adds SQLAlchemy support to your Flask application.

%prep
%setup -q -n Flask-SQLAlchemy-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m pytest -v

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README
%{python_sitelib}/*

%changelog
* Thu Oct 12 2017 arun@gmx.de
- update to version 2.3.2:
  * Don't mask the parent table for single-table inheritance
    models. (#561)
* Tue Oct 10 2017 arun@gmx.de
- specfile:
  * increased SQLAlchemy dependency to >= 0.8
  * changed from nose to pytest
  * added fdupes to remove some rpmlint warnings
- update to version 2.3.1:
  * If a model has a table name that matches an existing table in the
    metadata, use that table. Fixes a regression where reflected
    tables were not picked up by models. (#551)
  * Raise the correct error when a model has a table name but no
    primary key. (#556)
  * Fix repr on models that don't have an identity because they have
    not been flushed yet. (#555)
  * Allow specifying a max_per_page limit for pagination, to avoid
    users specifying high values in the request args. (#542)
  * For paginate with error_out=False, the minimum value for page is 1
    and per_page is 0. (#558)
- changes from version 2.3.0:
  * Multiple bugs with __tablename__ generation are fixed. Names will
    be generated for models that define a primary key, but not for
    single-table inheritance subclasses. Names will not override a
    declared_attr. PrimaryKeyConstraint is detected. (#541)
  * Passing an existing declarative_base() as model_class to
    SQLAlchemy.__init__ will use this as the base class instead of
    creating one. This allows customizing the metaclass used to
    construct the base. (#546)
  * The undocumented DeclarativeMeta internals that the extension uses
    for binds and table name generation have been refactored to work
    as mixins. Documentation is added about how to create a custom
    metaclass that does not do table name generation. (#546)
  * Model and metaclass code has been moved to a new models
    module. _BoundDeclarativeMeta is renamed to DefaultMeta; the old
    name will be removed in 3.0. (#546)
  * Models have a default repr that shows the model name and primary
    key. (#530)
  * Fixed a bug where using init_app would cause connectors to always
    use the current_app rather than the app they were created
    for. This caused issues when multiple apps were registered with
    the extension. (#547)
- changes from version 2.2:
  * Minimum SQLAlchemy version is 0.8 due to use of
    sqlalchemy.inspect.
  * Added support for custom query_class and model_class as args to
    the SQLAlchemy constructor. (#328)
  * Allow listening to SQLAlchemy events on db.session. (#364)
  * Allow __bind_key__ on abstract models. (#373)
  * Allow SQLALCHEMY_ECHO to be a string. (#409)
  * Warn when SQLALCHEMY_DATABASE_URI is not set. (#443)
  * Don't let pagination generate invalid page numbers. (#460)
  * Drop support of Flask < 0.10. This means the db session is always
    tied to the app context and its teardown event. (#461)
  * Tablename generation logic no longer accesses class properties
    unless they are declared_attr. (#467)
* Sat Oct  7 2017 arun@gmx.de
- convert to single spec
- update copyright
* Thu Sep 15 2016 toddrme2178@gmail.com
- Update to Version 2.1
  - Table names are automatically generated in more cases, including
    subclassing mixins and abstract models.
  - Allow using a custom MetaData object.
  - Add support for binds parameter to session.
- Update to Version 2.0
  - Changed how the builtin signals are subscribed to skip non Flask-SQLAlchemy
    sessions.  This will also fix the attribute error about model changes
    not existing.
  - Added a way to control how signals for model modifications are tracked.
  - Made the ``SignallingSession`` a public interface and added a hook
    for customizing session creation.
  - If the ``bind`` parameter is given to the signalling session it will no
    longer cause an error that a parameter is given twice.
  - Added working table reflection support.
  - Enabled autoflush by default.
  - Consider ``SQLALCHEMY_COMMIT_ON_TEARDOWN`` harmful and remove from docs.
- Update to Version 1.0
  - Added Python 3.3 support.
  - Dropped 2.5 compatibility.
  - Various bugfixes
  - Changed versioning format to do major releases for each update now.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 0.16:
  + New distribution format (flask_sqlalchemy)
  + Added support for Flask 0.9 specifics.
* Thu Nov 24 2011 saschpe@suse.de
- Fix bnc#732325
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.15:
  + Added session support for multiple databases
* Wed Jul 20 2011 saschpe@gmx.de
- Initial version
